@@ -3,7 +3,13 @@ from threading import Thread
 from urllib import urlencode
 
 
+LEVELS = ('debug', 'info', 'warning', 'error', 'critical')
+
+
 def stuff(url, user, log, level, message, **kwargs):
+    """
+    Puts the data to remote location
+    """
     data = kwargs
     data.update({
         'user': user,
@@ -17,22 +23,29 @@ def stuff(url, user, log, level, message, **kwargs):
     urllib2.urlopen(url, urlencode(data))
 
 
+
 class Logger(object):
-    def __init__(self, url, user, log):
+    def __init__(self, url, user, log, min_level=None):
         self._url = url
         self._user = user
         self._log = log
+        self._min_level_idx = min_level and LEVELS.index(min_level)
 
     def log(self, level, message, **kwargs):
         """
         Thread wrapper for stuff
         """
-        thread = Thread(
-            target=stuff,
-            args=(self._url, self._user, self._log, level, message),
-            kwargs=kwargs
-            )
-        thread.start()
+        try:
+            idx = LEVELS.index(level)
+        except ValueError:
+            idx = None
+        if self._min_level_idx == None or idx == None or idx >= self._min_level_idx:
+            thread = Thread(
+                target=stuff,
+                args=(self._url, self._user, self._log, level, message),
+                kwargs=kwargs
+                )
+            thread.start()
 
     def debug(self, message, **kwargs):
         self.log('debug', message, **kwargs)
@@ -48,4 +61,3 @@ class Logger(object):
 
     def critical(self, message, **kwargs):
         self.log('critical', message, **kwargs)
-
